# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['metprint']

package_data = \
{'': ['*']}

setup_kwargs = {
    'name': 'metprint',
    'version': '2020.7.1',
    'description': 'Pretty print text in a range of builtin formats or make your own',
    'long_description': '[![Github top language](https://img.shields.io/github/languages/top/FHPythonUtils/MetPrint.svg?style=for-the-badge)](../../)\n[![Codacy grade](https://img.shields.io/codacy/grade/4361c2b314a94e77a69b674885d7393a.svg?style=for-the-badge)](https://www.codacy.com/gh/FHPythonUtils/MetPrint)\n[![Repository size](https://img.shields.io/github/repo-size/FHPythonUtils/MetPrint.svg?style=for-the-badge)](../../)\n[![Issues](https://img.shields.io/github/issues/FHPythonUtils/MetPrint.svg?style=for-the-badge)](../../issues)\n[![License](https://img.shields.io/github/license/FHPythonUtils/MetPrint.svg?style=for-the-badge)](/LICENSE.md)\n[![Commit activity](https://img.shields.io/github/commit-activity/m/FHPythonUtils/MetPrint.svg?style=for-the-badge)](../../commits/master)\n[![Last commit](https://img.shields.io/github/last-commit/FHPythonUtils/MetPrint.svg?style=for-the-badge)](../../commits/master)\n[![PyPI Downloads](https://img.shields.io/pypi/dm/metprint.svg?style=for-the-badge)](https://pypi.org/project/metprint/)\n[![PyPI Version](https://img.shields.io/pypi/v/metprint.svg?style=for-the-badge)](https://pypi.org/project/metprint/)\n\n<!-- omit in TOC -->\n# MetPrint\n\n<img src="readme-assets/icons/name.png" alt="Project Icon" width="750">\n\nPretty print text in a range of builtin formats or make your own\n\nExample usage in your project\n```python\nfrom metprint import (\n\tLogType,\n\tLogger,\n\tMeterpreterFormatter,\n)\n\nmetLogger = Logger(MeterpreterFormatter())\nmetLogger.logPrint("none", LogType.NONE)\nmetLogger.logPrint("bold indent", LogType.BOLD, True)\nmetLogger.logPrint("italic indent", LogType.ITALIC, True)\nmetLogger.logPrint("header", LogType.HEADER)\nmetLogger.logPrint("debug", LogType.DEBUG)\nmetLogger.logPrint("info", LogType.INFO)\nmetLogger.logPrint("success", LogType.SUCCESS)\nmetLogger.logPrint("warning", LogType.WARNING)\nmetLogger.logPrint("error", LogType.ERROR)\nmetLogger.logPrint("critical", LogType.CRITICAL)\n```\n\nOutput of test.py\n<div>\n<img src="readme-assets/screenshots/desktop/screenshot-0.svg" alt="Screenshot 1" width="500">\n</div>\n\nAlternatively, you may prefer to make use of the `LAZY_PRINT` function.\nSet `builtins.METPRINT_LAZY_FORMATTER` to customize the formatter.\n\nAlso, you have the option to show dependencies some love with\n`builtins.METPRINT_DONATIONS` add a dictionary of projects and the\ndonations/ funding URL. Note that this is outputted on import.\n\nSee below for example usage of these.\n```python\n#!/usr/bin/env python3\n"""Test metprint LAZY_PRINT and donations\n"""\nimport builtins\n\n# Show some love to \'Test\'\nbuiltins.METPRINT_DONATIONS = {"Test": "Test URL"}\n# Set this if you want to set the LAZY_PRINT formatter\nbuiltins.METPRINT_LAZY_FORMATTER = "FHFormatter"\n\nfrom metprint import LAZY_PRINT, LogType\n\nprint("#########################")\nprint("#      FHFormatter      #")\nprint("#########################")\n# You will still need LogType for this\nLAZY_PRINT("none", LogType.NONE)\nLAZY_PRINT("bold", LogType.BOLD)\nLAZY_PRINT("italic", LogType.ITALIC)\nLAZY_PRINT("header", LogType.HEADER)\nLAZY_PRINT("debug", LogType.DEBUG)\nLAZY_PRINT("info", LogType.INFO)\nLAZY_PRINT("success", LogType.SUCCESS)\nLAZY_PRINT("warning", LogType.WARNING)\nLAZY_PRINT("error", LogType.ERROR)\nLAZY_PRINT("critical", LogType.CRITICAL)\n\n# Test that the donations message is not triggered again\n#pylint: disable=unused-import\nimport metprint\n```\n\nOutput of lazytest.py (for simplicity this is the output copied from the\nterminal so note that the actual output contains colours as above)\n```none\n1 project is looking for funding:\n\nTest: Test URL\n\n#########################\n#      FHFormatter      #\n#########################\nnone\nbold\nitalic\nheader\n[$  Deb] debug\n[* Info] info\n[+   Ok] success\n[/ Warn] warning\n[-  Err] error\n[! Crit] critical\n```\n\n- [Install With PIP](#install-with-pip)\n- [Language information](#language-information)\n\t- [Built for](#built-for)\n- [Install Python on Windows](#install-python-on-windows)\n\t- [Chocolatey](#chocolatey)\n\t- [Download](#download)\n- [Install Python on Linux](#install-python-on-linux)\n\t- [Apt](#apt)\n- [How to run](#how-to-run)\n\t- [With VSCode](#with-vscode)\n\t- [From the Terminal](#from-the-terminal)\n- [How to update, build and publish](#how-to-update-build-and-publish)\n- [Download](#download-1)\n\t- [Clone](#clone)\n\t\t- [Using The Command Line](#using-the-command-line)\n\t\t- [Using GitHub Desktop](#using-github-desktop)\n\t- [Download Zip File](#download-zip-file)\n- [Community Files](#community-files)\n\t- [Licence](#licence)\n\t- [Changelog](#changelog)\n\t- [Code of Conduct](#code-of-conduct)\n\t- [Contributing](#contributing)\n\t- [Security](#security)\n\n## Install With PIP\n\n```python\npip install metprint\n```\n\nHead to https://pypi.org/project/metprint/ for more info\n\n\n## Language information\n### Built for\nThis program has been written for Python 3 and has been tested with\nPython version 3.8.0 <https://www.python.org/downloads/release/python-380/>.\n\n## Install Python on Windows\n### Chocolatey\n```powershell\nchoco install python\n```\n### Download\nTo install Python, go to <https://www.python.org/> and download the latest\nversion.\n\n## Install Python on Linux\n### Apt\n```bash\nsudo apt install python3.8\n```\n\n## How to run\n### With VSCode\n1. Open the .py file in vscode\n2. Ensure a python 3.8 interpreter is selected (Ctrl+Shift+P > Python:Select\nInterpreter > Python 3.8)\n3. Run by pressing Ctrl+F5 (if you are prompted to install any modules, accept)\n### From the Terminal\n```bash\n./[file].py\n```\n\n## How to update, build and publish\n\n1. Ensure you have installed the following dependencies\n\tLinux\n\t```bash\n\twget dephell.org/install | python3.8\n\twget https://raw.githubusercontent.com/python-poetry/poetry/master/get-poetry.py | python3.8\n\t```\n\tWindows\n\t```powershell\n\t(wget dephell.org/install -UseBasicParsing).Content | python\n\t(wget https://raw.githubusercontent.com/python-poetry/poetry/master/get-poetry.py -UseBasicParsing).Content | python\n\t```\n2. Use poetry for the heavy lifting and dephell to generate requirements\n\t```bash\n\tpoetry update\n\tdephell deps convert\n\t```\n3. Build/ Publish\n\t```bash\n\tpoetry build\n\tpoetry publish\n\t```\n\tor\n\t```bash\n\tpoetry publish --build\n\t```\n\n\n## Download\n### Clone\n#### Using The Command Line\n1. Press the Clone or download button in the top right\n2. Copy the URL (link)\n3. Open the command line and change directory to where you wish to\nclone to\n4. Type \'git clone\' followed by URL in step 2\n```bash\n$ git clone https://github.com/FHPythonUtils/MetPrint\n```\n\nMore information can be found at\n<https://help.github.com/en/articles/cloning-a-repository>\n\n#### Using GitHub Desktop\n1. Press the Clone or download button in the top right\n2. Click open in desktop\n3. Choose the path for where you want and click Clone\n\nMore information can be found at\n<https://help.github.com/en/desktop/contributing-to-projects/cloning-a-repository-from-github-to-github-desktop>\n\n### Download Zip File\n\n1. Download this GitHub repository\n2. Extract the zip archive\n3. Copy/ move to the desired location\n\n## Community Files\n### Licence\nMIT License\nCopyright (c) FredHappyface\n(See the [LICENSE](/LICENSE.md) for more information.)\n\n### Changelog\nSee the [Changelog](/CHANGELOG.md) for more information.\n\n### Code of Conduct\nIn the interest of fostering an open and welcoming environment, we\nas contributors and maintainers pledge to make participation in our\nproject and our community a harassment-free experience for everyone.\nPlease see the\n[Code of Conduct](https://github.com/FHPythonUtils/.github/blob/master/CODE_OF_CONDUCT.md) for more information.\n\n### Contributing\nContributions are welcome, please see the [Contributing Guidelines](https://github.com/FHPythonUtils/.github/blob/master/CONTRIBUTING.md) for more information.\n\n### Security\nThank you for improving the security of the project, please see the [Security Policy](https://github.com/FHPythonUtils/.github/blob/master/SECURITY.md) for more information.\n',
    'author': 'FredHappyface',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/FHPythonUtils/MetPrint',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
